"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DialogContainer = void 0;
var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _react = _interopRequireWildcard(require("react"));
var _get2 = _interopRequireDefault(require("lodash/get"));
var _useUi = require("@webiny/app/hooks/useUi");
var _Dialog = require("@webiny/ui/Dialog");
var _Button = require("@webiny/ui/Button");
var DialogContainer = function DialogContainer() {
  var ui = (0, _useUi.useUi)();
  var _useState = (0, _react.useState)(false),
    _useState2 = (0, _slicedToArray2.default)(_useState, 2),
    isLoading = _useState2[0],
    setIsLoading = _useState2[1];
  var message = (0, _get2.default)(ui, "dialog.message");
  var _get = (0, _get2.default)(ui, "dialog.options", {}),
    dataTestId = _get.dataTestId,
    title = _get.title,
    loading = _get.loading,
    _get$actions = _get.actions,
    actions = _get$actions === void 0 ? {
      cancel: null,
      accept: {
        label: "OK"
      }
    } : _get$actions,
    style = _get.style,
    onClose = _get.onClose;
  var hideDialog = (0, _react.useCallback)(function () {
    ui.setState(function (ui) {
      return (0, _objectSpread2.default)((0, _objectSpread2.default)({}, ui), {}, {
        dialog: null
      });
    });
    if (typeof onClose === "function") {
      onClose();
    }
  }, [ui]);
  /**
   * We need this part because message can change while the dialog is opened and in loading state.
   */
  (0, _react.useEffect)(function () {
    setIsLoading(false);
  }, [ui?.dialog?.message]);
  var handleConfirm = async function handleConfirm() {
    if (!actions.accept.onClick) {
      /**
       * Should not happen as users should define "accept.onClick" function, but just in case lets show the information.
       * Possible to happen in development process.
       */
      console.info("There is no actions.accept.onClick callback defined.");
      hideDialog();
      return;
    }
    setIsLoading(true);
    await actions.accept.onClick();
    setIsLoading(false);
    hideDialog();
  };
  return /*#__PURE__*/_react.default.createElement(_Dialog.Dialog, {
    open: !!message,
    onClose: hideDialog,
    "data-testid": dataTestId,
    style: style
  }, isLoading ? loading : null, title && /*#__PURE__*/_react.default.createElement(_Dialog.DialogTitle, null, title), /*#__PURE__*/_react.default.createElement(_Dialog.DialogContent, null, message), /*#__PURE__*/_react.default.createElement(_Dialog.DialogActions, null, actions.cancel && /*#__PURE__*/_react.default.createElement(_Dialog.DialogAccept, {
    onClick: actions.cancel.onClick
  }, actions.cancel.label), actions.accept && /*#__PURE__*/_react.default.createElement(_Button.ButtonPrimary, {
    "data-testid": "confirmationdialog-confirm-action",
    onClick: handleConfirm
  }, actions.accept.label)));
};
exports.DialogContainer = DialogContainer;

//# sourceMappingURL=Dialog.js.map